@@ -1,6 +1,6 @@
-# -*- ruby encoding: utf-8 -*-
+# frozen_string_literal: true
 
-require 'spec_helper'
+require "spec_helper"
 
 describe "Diff::LCS.traverse_sequences" do
   describe "callback with no finishers" do
@@ -48,14 +48,14 @@ describe "Diff::LCS.traverse_sequences" do
       end
 
       it "has the correct LCS result on left-matches" do
-        expect(@callback.matched_a).to eq(hello.split(//))
+        expect(@callback.matched_a).to eq(hello.chars)
       end
 
       it "has the correct LCS result on right-matches" do
-        expect(@callback.matched_b).to eq(hello.split(//))
+        expect(@callback.matched_b).to eq(hello.chars)
       end
 
-      it "has the correct skipped sequences with the left sequence", :only => true do
+      it "has the correct skipped sequences with the left sequence" do
         expect(@callback.discards_a).to be_empty
       end
 
@@ -127,13 +127,11 @@ describe "Diff::LCS.traverse_sequences" do
     end
 
     it "has done markers differently-sized sequences" do
-      expect(@callback_s1_s2.done_a).to eq([[ "p", 9, "s", 10 ]])
+      expect(@callback_s1_s2.done_a).to eq([["p", 9, "t", 11]])
       expect(@callback_s1_s2.done_b).to be_empty
 
-      # 20110731 I don't yet understand why this particular behaviour
-      # isn't transitive.
       expect(@callback_s2_s1.done_a).to be_empty
-      expect(@callback_s2_s1.done_b).to be_empty
+      expect(@callback_s2_s1.done_b).to eq([["t", 11, "p", 9]])
     end
   end
 end
